@@ -11,6 +11,7 @@ use File::pushd;
 use CPAN::Meta;
 use Module::CPANfile;
 use Config::Identity::PAUSE;
+use Module::Runtime qw(require_module);
 
 use Minilla;
 use Minilla::Logger;
@@ -42,7 +43,7 @@ has module_maker => (
             $klass = $klass =~ s/^\+// ? $klass : "Minilla::ModuleMaker::$klass";
             return $klass->new();
         }
-        Minilla::ModuleMaker::ModuleBuild->new()
+        Minilla::ModuleMaker::ModuleBuildTiny->new()
     },
     lazy => 1,
 );
@@ -110,12 +111,6 @@ sub allow_pureperl {
     $self->config->{allow_pureperl} ? 1 : 0;
 }
 
-sub module_build_version {
-    my $self = shift;
-    # --pureperl-only support was added in 0.4005
-    $self->allow_pureperl ? 0.4005 : 0.38;
-}
-
 sub version {
     my $self = shift;
     my $version = $self->config->{version} || $self->metadata->version;
@@ -224,12 +219,35 @@ sub config {
         if ($err) {
             errorf("TOML error in %s: %s\n", $toml_path, $err);
         }
+        $self->_patch_config_for_mb($conf) unless $conf->{module_maker};
         $conf;
     } else {
         +{};
     }
 }
 
+sub _patch_config_for_mb {
+    my($self, $conf) = @_;
+
+    if (exists $conf->{build} or exists $conf->{XSUtil}) {
+        warn <<WARN unless $self->{__already_warned}++;
+!
+! WARNING:
+! module_maker is not set in your Minilla config (minil.toml), but found [build] or [XSUtil] section in it.
+! Defaulting to Module::Build, but you're suggested to add the following to your minil.toml:
+!
+!   module_maker="ModuleBuild"
+!
+! This friendly warning will go away in the next major release, and Minilla will default to ModuleBuildTiny
+! when module_maker is not explicitly set in minil.toml.
+!
+WARN
+        $conf->{module_maker} = "ModuleBuild";
+    }
+
+    return;
+}
+
 sub c_source {
     my $self = shift;
     $self->config->{c_source} ? join(' ', @{$self->config->{c_source}}) : '';
@@ -579,10 +597,16 @@ sub generate_minil_toml {
 sub regenerate_readme_md {
     my $self = shift;
 
-    require Pod::Markdown;
-    Pod::Markdown->VERSION('1.322');
+    my $markdown_maker = $self->config->{markdown_maker} || 'Pod::Markdown';
+    require_module($markdown_maker);
+    if ($markdown_maker eq 'Pod::Markdown') {
+        $markdown_maker->VERSION('1.322');
+    }
 
-    my $parser = Pod::Markdown->new;
+    my $parser = $markdown_maker->new;
+    if (not $parser->isa('Pod::Markdown')) {
+        errorf("'markdown_maker' config key must be a subclass of Pod::Markdown\n");
+    }
     $parser->parse_from_file($self->readme_from);
 
     my $fname = File::Spec->catfile($self->dir, 'README.md');
@@ -630,6 +654,8 @@ sub verify_prereqs {
 sub _build_contributors {
     my $self = shift;
 
+    return [] unless (`git show-ref --head`);
+
     my $normalize = sub {
         local $_ = shift;
         if (/<([^>]+)>/) {
